@@ -24,7 +24,6 @@ import sys
 from pathlib import Path
 import warnings
 
-import numpy as np
 
 import mylogging
 
@@ -32,6 +31,7 @@ from . import paths
 from . import misc
 
 # Lazy imports
+# import numpy as np
 # import inspect
 # import ast
 
@@ -71,6 +71,10 @@ def run_gui(devel=None, log_file_path=None, is_multiprocessing=False, builded_gu
         builded_gui_path ((str, Path, None)), optional): Where the web asset is. Only if debug is 0 but not run with pyinstaller.
             If None, it's automatically find (but is slower then). If 'default', path from project-starter is used - 'gui/web_builded'
             is used. Defaults to 'default'.
+
+    If you want to understand this technology more into detail, check this tutorial
+
+    https://mypythontools.readthedocs.io/pyvueeel-tutorial.html
     """
 
     # Just for lazy load of eel for users that will not use this module
@@ -219,6 +223,7 @@ def to_vue_plotly(data, names=None):
     """
 
     import pandas as pd
+    import numpy as np
 
     if isinstance(data, (np.ndarray, np.generic)):
         data = pd.DataFrame(data, columns=names)
@@ -247,6 +252,7 @@ def to_table(df, index=False):
         dict: DatPa in form for creating table in Vuetify v-data-table.
     """
     import pandas as pd
+    import numpy as np
 
     if not isinstance(df, pd.DataFrame):
         raise TypeError(
@@ -269,135 +275,3 @@ def to_table(df, index=False):
     headers = [{"text": i, "value": i, "sortable": True} for i in data.columns]
 
     return {"table": data.to_dict("records"), "headers": headers}
-
-
-def help_starter_pack_vue_app():
-    """
-    Py, Vue and eel
-    ===============
-
-    How to develop application with these tools and how to use mypythontools functions in such an app.
-
-    It's recomended way to download ``project-starter`` where all the files for gui are already edited and ready to use.
-    There are also working examples of calling from python to js and vice versa as well as example of alerting or plotting.
-
-    https://github.com/Malachov/mypythontools/tree/master/content
-
-    If you want to build just what is necassaty from scratch, you can use this tutorial.
-    Go in web documentation on readthedocs if reading from IDE
-
-
-    Structure::
-    -----------
-
-        - myproject
-            - gui
-                - generated with Vue CLI
-            - app.py
-
-    app.py
-    ------
-
-    >>> from mypythontools import pyvueeel
-    >>> from mypythontools.pyvueeel import expose
-    ...
-    >>> # Expose python functions to Js with decorator
-    >>> @expose
-    ... def load_data(settings):
-    ...     return {'Hello': 1}
-    >>> if __name__ == '__main__':
-    ...     pyvueeel.run_gui()
-
-    You can return dict - will be object in js
-    You can return list - will be an array in js
-
-    **Call js function from Py**::
-
-        pyvueeel.eel.load_data()
-
-    gui
-    ---
-
-    Generate gui folder with Vue CLI::
-
-        npm install -g @vue/cli
-        vue create gui
-
-    Goto folder and optionally::
-
-        vue add vuex
-        vue add vuetify
-        vue add router
-
-    main.js
-    -------::
-
-        if (process.env.NODE_ENV == 'development') {
-
-        try {
-            window.eel.set_host("ws://localhost:8686");
-
-        } catch (error) {
-            document.getElementById('app').innerHTML = 'Py side is not running. Start app.py with debugger.'
-            console.error(error);
-        }
-
-        Vue.config.productionTip = true
-        Vue.config.devtools = true
-        } else {
-        Vue.config.productionTip = false
-        Vue.config.devtools = false
-        }
-
-    You can expose function to be callable from python. Import and then
-    window.eel.expose(function_name, 'function_name')
-
-    .env
-    ----
-
-    Create empty files .env.development and add `VUE_APP_EEL=http://localhost:8686/eel.js`
-
-    Create empty .env.production and add `VUE_APP_EEL=eel.js`
-
-
-    index.html
-    ----------
-
-    In public folder add to index.html::
-
-        <script type="text/javascript" src="<%= VUE_APP_EEL %>"></script>
-
-    vue.config.js
-    -------------::
-
-        let devtool_mode
-
-        if (process.env.NODE_ENV === "development") {
-          devtool_mode = "source-map";
-        } else {
-          devtool_mode = false;
-        }
-
-        module.exports = {
-          outputDir: "web_builded",
-          transpileDependencies: ["vuetify"],
-          productionSourceMap: process.env.NODE_ENV != "production",
-
-          configureWebpack: {
-            devtool: devtool_mode,
-          },
-        };
-
-
-    Tips, trics
-    -----------
-
-    **VS Code plugins for developing**
-
-    - npm
-    - vetur
-    - Vue VSCode Snippets
-    - vuetify-vscode
-    """
-
-    print(help_starter_pack_vue_app.__doc__)
